@@ -92,7 +92,7 @@ pub fn macro_derive_scan_pg(input: TokenStream) -> TokenStream {
 
 
 #[proc_macro_attribute]
-pub fn table(args: TokenStream, input: TokenStream) -> TokenStream {
+pub fn crud(args: TokenStream, input: TokenStream) -> TokenStream {
     let mut cargo_data = "".to_string();
     let mut f = File::open("Cargo.lock").unwrap();
     f.read_to_string(&mut cargo_data).unwrap();
